pub struct CustomScheduler<A, F>{ /* private fields */ }Expand description
A custom scheduler that uses a closure to compute the learning rate
Implementations
Sourceimpl<A, F> CustomScheduler<A, F>
impl<A, F> CustomScheduler<A, F>
Sourcepub fn new(_initial_lr: A, lrfunc: F) -> CustomScheduler<A, F>
pub fn new(_initial_lr: A, lrfunc: F) -> CustomScheduler<A, F>
Create a new custom scheduler with the given initial learning rate and computation function
Arguments
initial_lr- The initial learning rate (used only for documentation)lr_func- A function that takes the current step count and returns the learning rate
Example
use optirs_core::schedulers::{CustomScheduler, LearningRateScheduler};
// Create a scheduler that reduces the learning rate by 10% every 10 steps
let mut scheduler = CustomScheduler::new(0.1, |step| {
0.1 * 0.9_f64.powi((step / 10) as i32)
});
assert_eq!(scheduler.get_learning_rate(), 0.1);
scheduler.step();Sourcepub fn get_step_count(&self) -> usize
pub fn get_step_count(&self) -> usize
Get the current step count